@@ -1,5 +1,5 @@
 from .diversity_indices import diversity_indices
-from .relative_intensity import relative_intensity
+from .normalise_intensity import normalise_intensity
 from .bray_curtis_matrix import bray_curtis_matrix
 from .ordination_matrix import ordination_matrix
-from .compound_class import compound_class
\ No newline at end of file
+from .compound_class import compound_class
