@@ -1,6 +1,6 @@
 import pandas as pd
 import numpy as np
-def ordination_matrix(molecular_formulas = [],peak_intensities=[],group_names = [], impute_value = 0):
+def ordination_matrix(molecular_formulas = [],peak_intensities=[],group_names = [], impute_value = 'nan'):
     """ 
 	Docstring for function pyKrev.ordination_matrix
 	====================
@@ -44,4 +44,4 @@ def ordination_matrix(molecular_formulas = [],peak_intensities=[],group_names =
                 ordination_mat.iloc[row_index,col_index] = impute_value #set the value to impute_value 
                 row_index += 1 #move down a row
         col_index += 1 #move across to the next column i.e. formula
-    return ordination_mat
\ No newline at end of file
+    return ordination_mat
