@@ -8,5 +8,7 @@ from .standardize_formula import standardize_formula
 from .unique_formula import unique_formula 
 from .find_intersections import find_intersections
 from .read_formularity import read_formularity
+from .read_batch_formularity import read_batch_formularity
 from .calculate_mass import calculate_mass
-from .kendrick_mass_defect import kendrick_mass_defect
\ No newline at end of file
+from .kendrick_mass_defect import kendrick_mass_defect
+from .filter_spectral_interference import filter_spectral_interference
\ No newline at end of file
